Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/matomo-org/matomo.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/API/API.php')
-rw-r--r--plugins/API/API.php30
1 files changed, 20 insertions, 10 deletions
diff --git a/plugins/API/API.php b/plugins/API/API.php
index b1a852c09a..0e52290c5f 100644
--- a/plugins/API/API.php
+++ b/plugins/API/API.php
@@ -38,7 +38,7 @@ use Piwik\Widget\WidgetsList;
require_once PIWIK_INCLUDE_PATH . '/core/Config.php';
/**
- * This API is the <a href='http://piwik.org/docs/analytics-api/metadata/' rel='noreferrer' target='_blank'>Metadata API</a>: it gives information about all other available APIs methods, as well as providing
+ * This API is the <a href='http://matomo.org/docs/analytics-api/metadata/' rel='noreferrer' target='_blank'>Metadata API</a>: it gives information about all other available APIs methods, as well as providing
* human readable and more complete outputs than normal API methods.
*
* Some of the information that is returned by the Metadata API:
@@ -50,8 +50,8 @@ require_once PIWIK_INCLUDE_PATH . '/core/Config.php';
* conversion rate, time on site, etc. which are not directly available in other methods.</li>
* <li>the method "getSuggestedValuesForSegment" returns top suggested values for a particular segment. It uses the Live.getLastVisitsDetails API to fetch the most recently used values, and will return the most often used values first.</li>
* </ul>
* The Metadata API is for example used by the Piwik Mobile App to automatically display all Piwik reports, with translated report & columns names and nicely formatted values.
* More information on the <a href='http://piwik.org/docs/analytics-api/metadata/' rel='noreferrer' target='_blank'>Metadata API documentation page</a>
*
* @method static \Piwik\Plugins\API\API getInstance()
*/
@@ -74,16 +74,26 @@ class API extends \Piwik\Plugin\API
}
/**
* Get Piwik version
* @return string
*/
- public function getPiwikVersion()
+ public function getMatomoVersion()
{
Piwik::checkUserHasSomeViewAccess();
return Version::VERSION;
}
/**
+ * Get Matomo version
+ * @return string
+ * @deprecated
+ */
+ public function getPiwikVersion()
+ {
+ return $this->getMatomoVersion();
+ }
+
+ /**
* Returns the most accurate IP address available for the current user, in
* IPv4 format. This could be the proxy client's IP address.
*
@@ -110,7 +120,7 @@ class API extends \Piwik\Plugin\API
* are not visible in the UI and not present in the API meta data. These columns are
* translated here.
* @return array
- * @deprecated since Piwik 2.15.1
+ * @deprecated since Matomo 2.15.1
*/
public function getDefaultMetricTranslations()
{
@@ -198,7 +208,7 @@ class API extends \Piwik\Plugin\API
*
* @param bool $pathOnly If true, returns path relative to doc root. Otherwise, returns a URL.
* @return string
- * @deprecated since Piwik 2.15.1
+ * @deprecated since Matomo 2.15.1
*/
public function getLogoUrl($pathOnly = false)
{
@@ -211,7 +221,7 @@ class API extends \Piwik\Plugin\API
*
* @param bool $pathOnly If true, returns path relative to doc root. Otherwise, returns a URL.
* @return string
- * @deprecated since Piwik 2.15.1
+ * @deprecated since Matomo 2.15.1
*/
public function getHeaderLogoUrl($pathOnly = false)
{
@@ -284,7 +294,7 @@ class API extends \Piwik\Plugin\API
$idSite = $idSites;
}
} elseif (empty($idSite) && empty($idSites)) {
- throw new \Exception('Calling API.getReportMetadata without any idSite is no longer supported since Piwik 3.0.0. Please specifiy at least one idSite via the "idSite" parameter.');
+ throw new \Exception('Calling API.getReportMetadata without any idSite is no longer supported since Matomo 3.0.0. Please specifiy at least one idSite via the "idSite" parameter.');
}
Piwik::checkUserHasViewAccess($idSite);
@@ -307,7 +317,7 @@ class API extends \Piwik\Plugin\API
}
/**
* Get a list of all pages that shall be shown in a Piwik UI including a list of all widgets that shall
* be shown within each page.
*
* @param int $idSite
@@ -50,8 +50,8 @@ require_once PIWIK_INCLUDE_PATH . '/core/Config.php';
* <li>the method "getSuggestedValuesForSegment" returns top suggested values for a particular segment. It uses the Live.getLastVisitsDetails API to fetch the most recently used values, and will return the most often used values first.</li>
* </ul>
- * The Metadata API is for example used by the Piwik Mobile App to automatically display all Piwik reports, with translated report & columns names and nicely formatted values.
- * More information on the <a href='http://piwik.org/docs/analytics-api/metadata/' rel='noreferrer' target='_blank'>Metadata API documentation page</a>
+ * The Metadata API is for example used by the Matomo Mobile App to automatically display all Matomo reports, with translated report & columns names and nicely formatted values.
+ * More information on the <a href='http://matomo.org/docs/analytics-api/metadata/' rel='noreferrer' target='_blank'>Metadata API documentation page</a>
*
* @method static \Piwik\Plugins\API\API getInstance()
@@ -74,16 +74,26 @@ class API extends \Piwik\Plugin\API
}
/**
- * Get Piwik version
+ * Get Matomo version
* @return string
*/
@@ -307,7 +317,7 @@ class API extends \Piwik\Plugin\API
}
/**
- * Get a list of all pages that shall be shown in a Piwik UI including a list of all widgets that shall
+ * Get a list of all pages that shall be shown in a Matomo UI including a list of all widgets that shall
* be shown within each page.
*